@@ -76,11 +76,8 @@ class Module:
               os.path.exists(os.path.join(source_dir, "configure"))):
             return "autotools"
         else:
-            print("The source directory has unexpected content, please "
-                  "delete it and pull\nthe source again.")
             return None
 
-
 def setup(**kwargs):
     global config_dir
     config_dir = kwargs.get("config_dir", None)
